@@ -2,6 +2,11 @@ import json
 import os
 
 
+def export_variables(environment_variables):
+    for env_name, env_value in environment_variables.items():
+        os.environ[str(env_name)] = str(env_value)
+
+
 def set_environment_variables(json_file_path):
     """
     Read and set environment variables from a flat json file.
@@ -25,5 +30,4 @@ def set_environment_variables(json_file_path):
         with open(json_file_path) as json_file:
             env_vars = json.loads(json_file.read())
 
-            for env_name, env_value in env_vars.items():
-                os.environ[str(env_name)] = str(env_value)
+            export_variables(env_vars)
